@@ -2,6 +2,7 @@ import time
 import fero
 import uuid
 import io
+import datetime
 from fero import FeroError
 import pandas as pd
 from marshmallow import (
@@ -75,6 +76,14 @@ class AnalysisSchema(Schema):
     blueprint_name = fields.String(required=True)
 
 
+class RevisionSchema(Schema):
+    class Meta:
+        unknown = EXCLUDE
+
+    version = fields.Integer()
+    configured_blueprint = fields.Dict()
+
+
 class FactorSchema(Schema):
     name = fields.String(required=True)
     min = fields.Number(required=False)
@@ -277,6 +286,55 @@ class Analysis:
 
         return col_name
 
+    def is_retraining(self) -> bool:
+        """Checks if an analysis is currently be retrained.
+
+        :return: True if the analysis is in the process of being retrained, false otherwise.
+        :rtype: bool
+        """
+        self._refresh_analysis()
+        training = self.latest_revision_model_state == "T"
+        latest_revision = self.latest_revision
+        if not training:
+            self._refresh_analysis()
+            # requery if a new version somehow got created when we refreshed.  Do this until they match
+            if self.latest_revision != latest_revision:
+                return self.is_retraining()
+
+        return training
+
+    def revise(self):
+        """Triggers an analysis revision which causes the analysis to be retrained with any new data or changes in the process configurations.
+
+        This method will not revise the analysis if a new analysis is currently being trained.  It currently only supports revising an analysis with the previously selected options.
+
+        For more granular configuration of a revision please use the Fero Labs website.
+        """
+        # don't revise if currently training
+        if self.is_retraining():
+            return
+
+        latest_revision = self._client.get(
+            f"/api/analyses/{self.uuid}/revisions/{self.latest_revision}/"
+        )
+        latest_revision = RevisionSchema().load(latest_revision)
+        latest_blueprint = latest_revision["configured_blueprint"]
+
+        self._client.post(
+            f"/api/analyses/{self.uuid}/revisions/",
+            {
+                "description": f"Revision created via fero client on {datetime.datetime.now().isoformat()}",
+                "configured_blueprint": latest_blueprint,
+            },
+        )
+        self._refresh_analysis()
+
+    def _refresh_analysis(self):
+        """Reload the latest analysis data from the server"""
+        data = self._client.get(f"/api/analyses/{self.uuid}/")
+        schema = AnalysisSchema()
+        self._data = schema.load(data)
+
     def _upload_file(self, fp: IO, file_tag: str, prediction_type: str) -> str:
         """Uploads a single file to the uploaded files location. Returns id of workspace to check"""
 
